Resources
=========

* `QPDF Manual`_

* `PDF 1.7`_ ISO Specification PDF 32000-1:2008

* `Adobe Supplement to ISO 32000 BaseVersion 1.7 ExtensionLevel 3`_, Adobe Acrobat 9.0, June 2008, for AESv3

* Other `Adobe extensions`_ to the PDF specification

.. _QPDF Manual: https://qpdf.readthedocs.io/

.. _PDF 1.7: https://opensource.adobe.com/dc-acrobat-sdk-docs/standards/pdfstandards/pdf/PDF32000_2008.pdf

.. _Adobe extensions: https://www.adobe.com/devnet/pdf/pdf_reference.html

.. _Adobe Supplement to ISO 32000 BaseVersion 1.7 ExtensionLevel 3: https://www.adobe.com/content/dam/acom/en/devnet/pdf/adobe_supplement_iso32000.pdf

For information about copyrights and licenses, including those associated with the
images in this documentation, see the source tree file ``.reuse/dep5``.